summaryrefslogtreecommitdiffstats
path: root/chrome/browser/views
diff options
context:
space:
mode:
authordavemoore@chromium.org <davemoore@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-09-13 20:06:05 +0000
committerdavemoore@chromium.org <davemoore@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-09-13 20:06:05 +0000
commitc6032e8b0dccde8dc24598e8c93d870b8513a42e (patch)
tree97c064cf68644e68aa81ca2e7eeb73534871e593 /chrome/browser/views
parentee9372cbbc0bbeb8c8f06473409f3749eb443dd2 (diff)
downloadchromium_src-c6032e8b0dccde8dc24598e8c93d870b8513a42e.zip
chromium_src-c6032e8b0dccde8dc24598e8c93d870b8513a42e.tar.gz
chromium_src-c6032e8b0dccde8dc24598e8c93d870b8513a42e.tar.bz2
This is a second attempt of http://codereview.chromium.org/3175038
It failed the Vista Perf UI tests. This is because those tests close the browser upon an error. And they always get an error when the session is closed in the middle of the test. The new changes are in chrome/browser/automation/testing_automation_provider.cc BUG=50006 TEST=Run chrome under nested window manager using Xephyr (see http://code.google.com/p/chromium/wiki/LayoutTestsLinux) use --enable-logging=stderr --log-level=0 kill xephyr examine log. You should see X IO Error detected followed (not necessarily immediately) by successfully saved /tmp/tx/Default/Preferences successfully saved /tmp/tx/Local State successfully saved /tmp/tx/Local State successfully saved /tmp/tx/Default/Preferences along with no crash. BUG= TEST= Review URL: http://codereview.chromium.org/3364019 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@59269 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/views')
-rw-r--r--chrome/browser/views/bookmark_bar_view.cc7
1 files changed, 5 insertions, 2 deletions
diff --git a/chrome/browser/views/bookmark_bar_view.cc b/chrome/browser/views/bookmark_bar_view.cc
index 4aeab9c..f3ab049 100644
--- a/chrome/browser/views/bookmark_bar_view.cc
+++ b/chrome/browser/views/bookmark_bar_view.cc
@@ -19,6 +19,7 @@
#include "chrome/browser/bookmarks/bookmark_model.h"
#include "chrome/browser/bookmarks/bookmark_utils.h"
#include "chrome/browser/browser.h"
+#include "chrome/browser/browser_shutdown.h"
#include "chrome/browser/chrome_thread.h"
#include "chrome/browser/importer/importer_data_types.h"
#include "chrome/browser/metrics/user_metrics.h"
@@ -968,9 +969,11 @@ void BookmarkBarView::Loaded(BookmarkModel* model) {
}
void BookmarkBarView::BookmarkModelBeingDeleted(BookmarkModel* model) {
// The bookmark model should never be deleted before us. This code exists
// to check for regressions in shutdown code and not crash.
- NOTREACHED();
+ if (!browser_shutdown::ShuttingDownWithoutClosingBrowsers())
+ NOTREACHED();
// Do minimal cleanup, presumably we'll be deleted shortly.
NotifyModelChanged();
@@ -968,9 +969,11 @@ void BookmarkBarView::Loaded(BookmarkModel* model) {
}
void BookmarkBarView::BookmarkModelBeingDeleted(BookmarkModel* model) {
- // The bookmark model should never be deleted before us. This code exists
+ // In normal shutdown The bookmark model should never be deleted before us.
+ // When X exits suddenly though, it can happen, This code exists
// to check for regressions in shutdown code and not crash.